@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.4';
 extends 'App::bif';
 
 sub run {
@@ -21,7 +21,11 @@ sub run {
 
     $dbw->txn(
         sub {
-            $self->new_change( message => "drop issue $info->{id} <$uuid>", );
+            $self->new_change(
+                action  => "drop issue $info->{id} <$uuid>",
+                message => "    [  Dropped Issue:        ]\n"
+                  . "    [    ID: $info->{id}  ]",
+            );
 
             my $res = $dbw->xdo(
                 delete_from => 'issues',
@@ -56,7 +60,7 @@ bif-drop-issue - remove an issue from the repository
 
 =head1 VERSION
 
-0.1.2 (2014-10-08)
+0.1.4 (2014-10-27)
 
 =head1 SYNOPSIS
 
