@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.4';
 extends 'App::bif::log';
 
 sub run {
@@ -14,6 +14,7 @@ sub run {
     my $info = $self->get_project( $opts->{path} );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat /);
+    my $now = $self->now;
 
     my $sth = $db->xprepare(
         select => [
@@ -22,8 +23,10 @@ sub run {
             concat( qv('c'), 'changes.id' )->as('change_id'),
             'SUBSTR(changes.uuid,1,8) AS change_uuid',
             'project_deltas.title',
-            'changes.mtime',
-            'changes.mtimetz',
+            'changes.mtime AS mtime',
+            "changes.mtimetz AS mtimetz",
+            'changes.mtimetzhm AS mtimetzhm',
+            "$now - changes.mtime AS mtime_age",
             'changes.action',
             'COALESCE(changes.author,e.name) AS author',
             'COALESCE(changes.email,ecm.mvalue) AS email',
@@ -49,7 +52,7 @@ sub run {
         inner_join => 'entity_contact_methods ecm',
         on         => 'ecm.id = e.default_contact_method_id',
         left_join  => 'project_status',
-        on         => 'project_status.id = project_deltas.status_id',
+        on         => 'project_status.id = project_deltas.project_status_id',
         where      => {
             'project_deltas.project_id' => $info->{id},
         },
@@ -61,7 +64,12 @@ sub run {
     $self->start_pager;
 
     my $first = $sth->hashref;
+    $first->{ctime}     = $first->{mtime};
+    $first->{ctimetz}   = $first->{mtimetz};
+    $first->{ctimetzhm} = $first->{mtimetzhm};
+    $first->{ctime_age} = $first->{mtime_age};
     $self->log_item( $first, 'project', [ 'Phase', $first->{status} ] );
+
     $self->log_comment($_) for $sth->hashrefs;
 
     return $self->ok('LogProject');
@@ -78,7 +86,7 @@ bif-log-project - review a project history
 
 =head1 VERSION
 
-0.1.2 (2014-10-08)
+0.1.4 (2014-10-27)
 
 =head1 SYNOPSIS
 
