@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.4';
 extends 'App::bif::log';
 
 sub run {
@@ -14,6 +14,7 @@ sub run {
     my $info = $self->get_topic( $opts->{id}, 'task' );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat coalesce/);
+    my $now = $self->now;
 
     my $sth = $db->xprepare(
         select => [
@@ -22,8 +23,10 @@ sub run {
             concat( qv('c'), 'task_deltas.change_id' )->as('change_id'),
             'SUBSTR(changes.uuid,1,8) AS change_uuid',
             'task_deltas.title',
-            'changes.mtime',
-            'changes.mtimetz',
+            'changes.mtime AS mtime',
+            "changes.mtimetz AS mtimetz",
+            'changes.mtimetzhm AS mtimetzhm',
+            "$now - changes.mtime AS mtime_age",
             'changes.action',
             'COALESCE(changes.author,e.name) AS author',
             'COALESCE(changes.email,ecm.mvalue) AS email',
@@ -44,7 +47,7 @@ sub run {
         inner_join => 'topics t',
         on         => 't.id = task_deltas.task_id',
         left_join  => 'task_status',
-        on         => 'task_status.id = task_deltas.status_id',
+        on         => 'task_status.id = task_deltas.task_status_id',
         left_join  => 'projects',
         on         => 'projects.id = task_status.project_id',
         left_join  => 'hubs h',
@@ -62,7 +65,13 @@ sub run {
 
     $self->start_pager;
 
-    $self->log_item( $sth->hashref, 'task' );
+    my $first = $sth->hashref;
+    $first->{ctime}     = $first->{mtime};
+    $first->{ctimetz}   = $first->{mtimetz};
+    $first->{ctimetzhm} = $first->{mtimetzhm};
+    $first->{ctime_age} = $first->{mtime_age};
+    $self->log_item( $first, 'task' );
+
     $self->log_comment($_) for $sth->hashrefs;
 
     return $self->ok('LogTask');
@@ -79,7 +88,7 @@ bif-log-task - review a task history
 
 =head1 VERSION
 
-0.1.2 (2014-10-08)
+0.1.4 (2014-10-27)
 
 =head1 SYNOPSIS
 
