@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.4';
 extends 'App::bif';
 
 sub run {
@@ -55,8 +55,8 @@ sub run {
                     id         => $info->{id},
                     change_id  => $opts->{change_id},
                     project_id => $info->{project_id},
-                    $opts->{title} ? ( title     => $opts->{title} )   : (),
-                    @$status_ids   ? ( status_id => $status_ids->[0] ) : (),
+                    $opts->{title} ? ( title => $opts->{title} ) : (),
+                    @$status_ids ? ( issue_status_id => $status_ids->[0] ) : (),
                 },
             );
 
@@ -98,7 +98,7 @@ bif-update-issue - update an issue
 
 =head1 VERSION
 
-0.1.2 (2014-10-08)
+0.1.4 (2014-10-27)
 
 =head1 SYNOPSIS
 
