@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.4';
 extends 'App::bif';
 
 sub run {
@@ -52,8 +52,10 @@ sub run {
                 values      => {
                     id        => $info->{id},
                     change_id => $uid,
-                    $opts->{title} ? ( title     => $opts->{title} )   : (),
-                    $status_ids    ? ( status_id => $status_ids->[0] ) : (),
+                    $opts->{title} ? ( title => $opts->{title} ) : (),
+                    $status_ids
+                    ? ( project_status_id => $status_ids->[0] )
+                    : (),
                 },
             );
 
@@ -95,7 +97,7 @@ bif-update-project - update a project
 
 =head1 VERSION
 
-0.1.2 (2014-10-08)
+0.1.4 (2014-10-27)
 
 =head1 SYNOPSIS
 
