@@ -1,4 +1,4 @@
-CREATE TABLE func_change_project_status(
+CREATE TABLE func_update_project_status(
     change_id INTEGER NOT NULL,
     id INTEGER NOT NULL,
     status VARCHAR(40),
@@ -6,13 +6,13 @@ CREATE TABLE func_change_project_status(
 );
 
 CREATE TRIGGER
-    func_change_project_status_bi_1
+    func_update_project_status_bi_1
 BEFORE INSERT ON
-    func_change_project_status
+    func_update_project_status
 FOR EACH ROW BEGIN
 
     SELECT debug(
-        'TRIGGER func_change_project_status_bi_1',
+        'TRIGGER func_update_project_status_bi_1',
         NEW.change_id,
         NEW.id,
         NEW.status,
