@@ -1,7 +1,7 @@
 CREATE TABLE func_update_task(
     change_id INTEGER NOT NULL,
     id INTEGER NOT NULL,
-    status_id INTEGER,
+    task_status_id INTEGER,
     title VARCHAR
 );
 
@@ -15,7 +15,7 @@ FOR EACH ROW BEGIN
         'TRIGGER func_update_task_bi_1',
         NEW.id,
         NEW.change_id,
-        NEW.status_id,
+        NEW.task_status_id,
         NEW.title
     );
 
@@ -23,13 +23,13 @@ FOR EACH ROW BEGIN
         task_deltas(
             change_id,
             task_id,
-            status_id,
+            task_status_id,
             title
         )
     VALUES(
         NEW.change_id,
         NEW.id,
-        NEW.status_id,
+        NEW.task_status_id,
         NEW.title
     );
 
