@@ -50,12 +50,13 @@ BEGIN
     SET
         terms = terms || (
             SELECT
-                CASE WHEN
+                '-' || x'0A'
+                || CASE WHEN
                     NEW.new
                 THEN
-                    '- _: hub_repo' || x'0A'
+                    '  _: hub_repo' || x'0A'
                 ELSE
-                    '- _: hub_repo_delta' || x'0A'
+                    '  _: hub_repo_delta' || x'0A'
                     || '  hub_repo_uuid: ' || topics.uuid || x'0A'
                 END
                 || CASE WHEN
